<#ibiztemplate>
TARGET=PSSYSAPP
</#ibiztemplate>
<#if app.getAppMode()?? && app.getAppMode() == "WFAPP" && app.getAllPSAppWFs()??>
package ${pub.getPKGCodeName()}.${app.getPKGCodeName()?lower_case}.job;

import feign.Client;
import feign.Contract;
import feign.Feign;
import feign.codec.Decoder;
import feign.codec.Encoder;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.ApplicationArguments;
import org.springframework.boot.ApplicationRunner;
import org.springframework.stereotype.Component;
import org.springframework.cloud.openfeign.ribbon.LoadBalancerFeignClient;
import org.springframework.core.io.ClassPathResource;

import java.io.InputStream;
import java.util.List;
import java.util.ArrayList;

import ${pub.getPKGCodeName()}.util.config.SysInfoProperties;
import ${pub.getPKGCodeName()}.util.feign.FeignRequestInterceptor;
import ${pub.getPKGCodeName()}.util.config.UniWFClientProperties;
import ${pub.getPKGCodeName()}.util.feign.UniWFFeignClient;
import ${pub.getPKGCodeName()}.util.domain.PSWFVersion;
import ${pub.getPKGCodeName()}.util.domain.WFApp;

/**
 *
 */
@Component
public class WFAppJob implements ApplicationRunner {

    UniWFFeignClient uniWFFeignClient;

    @Autowired
    SysInfoProperties sysInfoProperties;

    @Autowired
    public WFAppJob(Decoder decoder, Encoder encoder, Client client, Contract contract, FeignRequestInterceptor feignRequestInterceptor, UniWFClientProperties uniWFClientProperties) {
        if (uniWFClientProperties.getServiceId()!=null) {
    		Feign.Builder nameBuilder = Feign.builder()
                    .client(client)
                    .encoder(encoder)
                    .decoder(decoder)
                    .contract(contract)
                    .requestInterceptor(feignRequestInterceptor)
                    ;
        	this.uniWFFeignClient = nameBuilder.target(UniWFFeignClient.class,"http://" + uniWFClientProperties.getServiceId() + "/") ;
		} else if (uniWFClientProperties.getServiceUrl()!=null) {
			if (client instanceof LoadBalancerFeignClient) {
				client = ((LoadBalancerFeignClient) client).getDelegate();
			}
			Feign.Builder nameBuilder = Feign.builder()
                    .client(client)
                    .encoder(encoder)
                    .decoder(decoder)
                    .contract(contract)
                    .requestInterceptor(feignRequestInterceptor)
                    ;
        	this.uniWFFeignClient = nameBuilder.target(UniWFFeignClient.class, "http://" + uniWFClientProperties.getServiceUrl() + "/") ;
		}
    }

    @Override
    public void run(ApplicationArguments args) throws Exception {
        /* ---------- 工作流应用注册内容 ---------- */

        // 注册业务工作流版本
        WFApp wfapp = new WFApp();
        wfapp.setWfappid(sysInfoProperties.getAppid());
        wfapp.setWfappname(sysInfoProperties.getAppname());
        wfapp.setPssystemid(sysInfoProperties.getSystemid());
        wfapp.setWorkflowid(sysInfoProperties.getDomainid());
        wfapp.setServiceid(sysInfoProperties.getServiceid());
        wfapp.setServiceurl(sysInfoProperties.getServiceurl());
        wfapp.setLogicname(sysInfoProperties.getApplogicname());
        uniWFFeignClient.registWFApp(wfapp);

        // 注册业务工作流版本
        List<PSWFVersion> pswfversions = new ArrayList<PSWFVersion>();
    <#assign i = 0>
    <#list app.getAllPSAppWFVers() as wfver>
        <#assign appwf = wfver.getPSAppWF()>
        <#assign wf = appwf.getPSWorkflow()>
        PSWFVersion pswfversion${i} = new PSWFVersion();
        pswfversion${i}.setPswfversionid("${wfver.getId()}");
        pswfversion${i}.setPswfversionname("${wfver.getCodeName()}");
        pswfversion${i}.setLogicname("${wfver.getName()}");
        <#if wfver.getPSWFVersion().getWFMode()??>
        pswfversion${i}.setWfmodeid("${wfver.getPSWFVersion().getWFMode()}");
        </#if>
        pswfversion${i}.setPsworkflowid("${wf.getId()}");
        pswfversion${i}.setPsworkflowname("${wf.getCodeName()}");
        pswfversion${i}.setWfappid(sysInfoProperties.getAppid());
        pswfversion${i}.setPssystemid(sysInfoProperties.getSystemid());
        pswfversion${i}.setWorkflowid(sysInfoProperties.getDomainid());
        // 文件传入
        ClassPathResource pswfversion${i}DesignFile = new ClassPathResource("workflow/${wfver.getCodeName()}.bpmn");
        InputStream pswfversion${i}Is = null;
        try {
            pswfversion${i}Is = pswfversion${i}DesignFile.getInputStream();
            byte[] pswfversion${i}Content = new byte[pswfversion${i}Is.available()];
            pswfversion${i}Is.read(pswfversion${i}Content);
            pswfversion${i}.setFilename(pswfversion${i}.getPswfversionid() + "${wfver.getCodeName()}.bpmn");
            pswfversion${i}.setFilecontent(pswfversion${i}Content);
        } catch (Exception e) {
            e.printStackTrace();
        } finally {
            if (pswfversion${i}Is != null) {
                try {
                    pswfversion${i}Is.close();
                } catch (Exception e2) {
                    e2.printStackTrace();
                }
            }
            pswfversion${i}Is = null;
        }
        pswfversions.add(pswfversion${i});
        <#assign i++>
    </#list>
        uniWFFeignClient.registPSWFVersion(pswfversions);
    }
}
</#if>
